$ zzfatorar 1200
1200 | 2
 600 | 2
 300 | 2
 150 | 2
  75 | 3
  25 | 5
   5 | 5
   1 |

1200 = 2^4 * 3 * 5^2
$

$ zzfatorar 8844
8844 | 2
4422 | 2
2211 | 3
 737 | 11
  67 | 67
   1 |

8844 = 2^2 * 3 * 11 * 67
$

$ zzfatorar 56877
56877 | 3
18959 | 18959
    1 |

56877 = 3 * 18959
$

$ zzfatorar 167                         #=> 167 é um número primo.
$ zzfatorar 1871                        #=> 1871 é um número primo.
